@@ -61,10 +61,12 @@ QString LmSensorsPlugin::providerName() const
 
 void LmSensorsPlugin::update()
 {
-    for (auto sensor : qAsConst(m_sensors)) {
+    for (auto sensor : std::as_const(m_sensors)) {
         sensor->update();
     }
 }
 
 K_PLUGIN_CLASS_WITH_JSON(LmSensorsPlugin, "metadata.json")
 #include "lmsensors.moc"
+
+#include "moc_lmsensors.cpp"
